@@ -100,19 +100,19 @@ proc rivet::parse { data outbufvar } {
 		}
 		switch -exact -- $cur {
 		    "\{" {
-			append outbuf "\\{"
+			append outbuf "\\\{"
 		    }
 		    "\}" {
-			append outbuf "\\}"
+			append outbuf "\\\}"
 		    }
 		    "\$" {
 			append outbuf "\\$"
 		    }
 		    "\[" {
-			append outbuf "\\["
+			append outbuf "\\\["
 		    }
 		    "\]" {
-			append outbuf "\\]"
+			append outbuf "\\\]"
 		    }
 		    "\"" {
 			append outbuf "\\\""
