@@ -177,10 +177,16 @@ proc call_page {{useenv ""} {createinterp 0}} {
 				if {[catch {
 					$myinterp eval [list parse $targetfile]
 				} err]} {
-					$myinterp eval [list rivet_error]
+					if {[info command $myinterp] != ""} {
+						$myinterp eval [list rivet_error]
+					}
 				}
 
 				# Flush the output stream
+				if {[info command $myinterp] == ""} {
+					return
+				}
+
 				$myinterp eval [list rivet_flush -final]
 
 				# Determine result
@@ -1512,7 +1518,7 @@ if {![info exists ::env(GATEWAY_INTERFACE)]} {
 			exit 0
 		}
 		"--version" {
-			tcl_puts "RivetStarkit version 0.5.1.0"
+			tcl_puts "RivetStarkit version 0.5.1.7"
 			exit 0
 		}
 		default {
